require 'test/unit'
require './lib/hash_extensions.rb'

class HashExtensionTest < Test::Unit::TestCase
  
  def test_converting_simple
    json = { "test" => "value" }
    hash = { :test => "value" }
    res = json.string_keys_to_symbol_keys
    assert_equal( hash, res )
  end

  def test_converting_multible_keys
    json = { "test" => "value", "another" => "valuestuff" }
    hash = { :test => "value", :another => "valuestuff" }
    res = json.string_keys_to_symbol_keys
    assert_equal( hash, res )
  end
  
  def test_converting_simple_with_array
    json = { "key" => [ "and", "value" ] }
    hash = { :key => [ "and", "value" ] }
    res = json.string_keys_to_symbol_keys
    assert_equal( hash, res )
  end

  def test_converting_with_subhashes
    json = { "key1" => { "key2" => "value" }}
    hash = { :key1 => { :key2 => "value" }}
    res = json.string_keys_to_symbol_keys
    assert_equal( hash, res )
  end

  def test_converting_with_subhashes_and_array
    json = { "key1" => { "key2" => ["va","lu","es"] }}
    hash = { :key1 => { :key2 => ["va","lu","es"] }}
    res = json.string_keys_to_symbol_keys
    assert_equal( hash, res )
  end

  def test_converting_with_array_of_hashes
    json = { "key1" => [ { "key2" => "avalue" }, {"key3" => "anothervalue" }] }
    hash = { :key1 => [ { :key2 => "avalue" }, { :key3 => "anothervalue" }] }
    res = json.string_keys_to_symbol_keys
    assert_equal( hash, res )
  end
  
  def test_converting_with_array_of_hashes_and_subhashes
    json = { "key1" => [ { "key2" => {"key21" => "val"} }, {"key3" => "anothervalue" }] }
    hash = { :key1 => [ { :key2 => {:key21 => "val"} }, { :key3 => "anothervalue" }] }
    res = json.string_keys_to_symbol_keys
    assert_equal( hash, res )
  end

end

